==> ms-users-12.1.1.tgz: package/src/accounts/init-dev.js <==
const Promise = require('bluebird');
const times = require('lodash/times');
const { CHALLENGE_TYPE_EMAIL } = require('../constants');

module.exports = function initFakeAccounts() {
  const faker = require('faker');

  const { config } = this;
  const accounts = times(103, () => ({
    id: faker.internet.email(),
    metadata: {
      firstName: faker.name.firstName(),
      lastName: faker.name.lastName(),
    },
    activate: true,
  }));

  const audience = config.jwt.defaultAudience;

  return Promise
    .map(accounts, (account) => {
      const opts = {
        params: {
          username: account.id,
          password: (Math.random() * 20).toFixed(20),
          audience,
          metadata: {
            firstName: account.metadata.firstName,
            lastName: account.metadata.lastName,
          },
          activate: true,
          challengeType: CHALLENGE_TYPE_EMAIL,
          skipPassword: false,
        },
      };

      return Promise
        .bind(this, ['register', opts])
        .spread(this.dispatch)
        .reflect();
    })
    .bind(this)
    .then(function reportStats(users) {
      const totalAccounts = users.length;
      const errors = [];
      let registered = 0;
      users.forEach((user) => {
        if (user.isFulfilled()) {
          registered += 1;
        } else {
          errors.push(user.reason());
        }
      });

      this.log.info(
        'Registered fake users %d/%d. Errors: %d',
        registered, totalAccounts, errors.length
      );

      errors.forEach((err) => {
        if (err.statusCode !== 403) {
          this.log.warn(err.stack);
        }
      });

      return null;
    });
};

==> ms-users-17.1.3.tgz: package/src/accounts/init-dev.js <==
const Promise = require('bluebird');
const times = require('lodash/times');
const { CHALLENGE_TYPE_EMAIL } = require('../constants');

module.exports = function initFakeAccounts() {
  const { faker } = require('@faker-js/faker');

  const { config } = this;
  const accounts = times(103, () => ({
    id: faker.internet.email(),
    metadata: {
      firstName: faker.person.firstName(),
      lastName: faker.person.lastName(),
    },
    activate: true,
  }));

  const audience = config.jwt.defaultAudience;

  return Promise
    .map(accounts, (account) => {
      const opts = {
        params: {
          username: account.id,
          password: (Math.random() * 20).toFixed(20),
          audience,
          metadata: {
            firstName: account.metadata.firstName,
            lastName: account.metadata.lastName,
          },
          activate: true,
          challengeType: CHALLENGE_TYPE_EMAIL,
          skipPassword: false,
        },
      };

      return Promise
        .bind(this, ['register', opts])
        .spread(this.dispatch)
        .reflect();
    })
    .bind(this)
    .then(function reportStats(users) {
      const totalAccounts = users.length;
      const errors = [];
      let registered = 0;
      users.forEach((user) => {
        if (user.isFulfilled()) {
          registered += 1;
        } else {
          errors.push(user.reason());
        }
      });

      this.log.info(
        'Registered fake users %d/%d. Errors: %d',
        registered,
        totalAccounts,
        errors.length
      );

      errors.forEach((err) => {
        if (err.statusCode !== 403) {
          this.log.warn(err.stack);
        }
      });

      return null;
    });
};
